declare const deepFreezeEs6: {
    exports: {};
};
declare function deepFreeze(obj: any): any;
declare var deepFreeze$1: {};
/** @typedef {import('highlight.js').CallbackResponse} CallbackResponse */
/** @typedef {import('highlight.js').CompiledMode} CompiledMode */
/** @implements CallbackResponse */
declare class AResponse {
    /**
     * @param {CompiledMode} mode
     */
    constructor(mode: any);
    ignoreMatch(): void;
}
/**
 * @param {string} value
 * @returns {string}
 */
declare function escapeHTML(value: any): any;
/**
 * performs a shallow merge of multiple objects into one
 *
 * @template T
 * @param {T} original
 * @param {Record<string,any>[]} objects
 * @returns {T} a single new object
 */
declare function inherit$1(original: any, ...objects: any[]): any;
/**
 * @typedef {object} Renderer
 * @property {(text: string) => void} addText
 * @property {(node: Node) => void} openNode
 * @property {(node: Node) => void} closeNode
 * @property {() => string} value
 */
/** @typedef {{kind?: string, sublanguage?: boolean}} Node */
/** @typedef {{walk: (r: Renderer) => void}} Tree */
/** */
declare const SPAN_CLOSE = "</span>";
/**
 * Determines if a node needs to be wrapped in <span>
 *
 * @param {Node} node */
declare const emitsWrappingTags: (node: any) => boolean;
/**
 *
 * @param {string} name
 * @param {{prefix:string}} options
 */
declare const expandScopeName: (name: any, { prefix }: {
    prefix: any;
}) => string;
/** @type {Renderer} */
declare class HTMLRenderer {
    /**
     * Creates a new HTMLRenderer
     *
     * @param {Tree} parseTree - the parse tree (must support `walk` API)
     * @param {{classPrefix: string}} options
     */
    constructor(parseTree: any, options: any);
    /**
     * Adds texts to the output stream
     *
     * @param {string} text */
    addText(text: any): void;
    /**
     * Adds a node open to the output stream (if needed)
     *
     * @param {Node} node */
    openNode(node: any): void;
    /**
     * Adds a node close to the output stream (if needed)
     *
     * @param {Node} node */
    closeNode(node: any): void;
    /**
     * returns the accumulated buffer
    */
    value(): any;
    /**
     * Builds a span element
     *
     * @param {string} className */
    span(className: any): void;
}
/** @typedef {{kind?: string, sublanguage?: boolean, children: Node[]} | string} Node */
/** @typedef {{kind?: string, sublanguage?: boolean, children: Node[]} } DataNode */
/** @typedef {import('highlight.js').Emitter} Emitter */
/**  */
declare class TokenTree {
    constructor();
    get top(): any;
    get root(): any;
    /** @param {Node} node */
    add(node: any): void;
    /** @param {string} kind */
    openNode(kind: any): void;
    closeNode(): any;
    closeAllNodes(): void;
    toJSON(): string;
    /**
     * @typedef { import("./html_renderer").Renderer } Renderer
     * @param {Renderer} builder
     */
    walk(builder: any): any;
    /**
     * @param {Renderer} builder
     * @param {Node} node
     */
    static _walk(builder: any, node: any): any;
    /**
     * @param {Node} node
     */
    static _collapse(node: any): void;
}
/**
  Currently this is all private API, but this is the minimal API necessary
  that an Emitter must implement to fully support the parser.

  Minimal interface:

  - addKeyword(text, kind)
  - addText(text)
  - addSublanguage(emitter, subLanguageName)
  - finalize()
  - openNode(kind)
  - closeNode()
  - closeAllNodes()
  - toHTML()

*/
/**
 * @implements {Emitter}
 */
declare class TokenTreeEmitter extends TokenTree {
    /**
     * @param {*} options
     */
    constructor(options: any);
    /**
     * @param {string} text
     * @param {string} kind
     */
    addKeyword(text: any, kind: any): void;
    /**
     * @param {string} text
     */
    addText(text: any): void;
    /**
     * @param {Emitter & {root: DataNode}} emitter
     * @param {string} name
     */
    addSublanguage(emitter: any, name: any): void;
    toHTML(): any;
    finalize(): boolean;
}
/**
 * @param {RegExp | string } re
 * @returns {string}
 */
declare function anyNumberOfTimes(re: any): string;
/**
 * @param {RegExp | string } re
 * @returns {string}
 */
declare function optional(re: any): string;
/**
 * @param {RegExp | string} re
 * @returns {number}
 */
declare function countMatchGroups(re: any): number;
/**
 * Does lexeme start with a regular expression match at the beginning
 * @param {RegExp} re
 * @param {string} lexeme
 */
declare function startsWith(re: any, lexeme: any): any;
declare const BACKREF_RE: RegExp;
/**
 * @param {(string | RegExp)[]} regexps
 * @param {{joinWith: string}} opts
 * @returns {string}
 */
declare function _rewriteBackreferences(regexps: any, { joinWith }: {
    joinWith: any;
}): any;
/** @typedef {import('highlight.js').Mode} Mode */
/** @typedef {import('highlight.js').ModeCallback} ModeCallback */
declare const MATCH_NOTHING_RE: RegExp;
declare const IDENT_RE = "[a-zA-Z]\\w*";
declare const UNDERSCORE_IDENT_RE = "[a-zA-Z_]\\w*";
declare const NUMBER_RE = "\\b\\d+(\\.\\d+)?";
declare const C_NUMBER_RE = "(-?)(\\b0[xX][a-fA-F0-9]+|(\\b\\d+(\\.\\d*)?|\\.\\d+)([eE][-+]?\\d+)?)";
declare const BINARY_NUMBER_RE = "\\b(0b[01]+)";
declare const RE_STARTERS_RE = "!|!=|!==|%|%=|&|&&|&=|\\*|\\*=|\\+|\\+=|,|-|-=|/=|/|:|;|<<|<<=|<=|<|===|==|=|>>>=|>>=|>=|>>>|>>|>|\\?|\\[|\\{|\\(|\\^|\\^=|\\||\\|=|\\|\\||~";
/**
* @param { Partial<Mode> & {binary?: string | RegExp} } opts
*/
declare const SHEBANG: (opts?: {}) => any;
declare const BACKSLASH_ESCAPE: {
    begin: string;
    relevance: number;
};
declare const APOS_STRING_MODE: {
    scope: string;
    begin: string;
    end: string;
    illegal: string;
    contains: {
        begin: string;
        relevance: number;
    }[];
};
declare const QUOTE_STRING_MODE: {
    scope: string;
    begin: string;
    end: string;
    illegal: string;
    contains: {
        begin: string;
        relevance: number;
    }[];
};
declare const PHRASAL_WORDS_MODE: {
    begin: RegExp;
};
/**
 * Creates a comment mode
 *
 * @param {string | RegExp} begin
 * @param {string | RegExp} end
 * @param {Mode | {}} [modeOptions]
 * @returns {Partial<Mode>}
 */
declare const COMMENT: (begin: any, end: any, modeOptions?: {}) => any;
declare const C_LINE_COMMENT_MODE: any;
declare const C_BLOCK_COMMENT_MODE: any;
declare const HASH_COMMENT_MODE: any;
declare const NUMBER_MODE: {
    scope: string;
    begin: string;
    relevance: number;
};
declare const C_NUMBER_MODE: {
    scope: string;
    begin: string;
    relevance: number;
};
declare const BINARY_NUMBER_MODE: {
    scope: string;
    begin: string;
    relevance: number;
};
declare const REGEXP_MODE: {
    begin: RegExp;
    contains: {
        scope: string;
        begin: RegExp;
        end: RegExp;
        illegal: RegExp;
        contains: ({
            begin: string;
            relevance: number;
        } | {
            begin: RegExp;
            end: RegExp;
            relevance: number;
            contains: {
                begin: string;
                relevance: number;
            }[];
        })[];
    }[];
};
declare const TITLE_MODE: {
    scope: string;
    begin: string;
    relevance: number;
};
declare const UNDERSCORE_TITLE_MODE: {
    scope: string;
    begin: string;
    relevance: number;
};
declare const METHOD_GUARD: {
    begin: string;
    relevance: number;
};
/**
 * Adds end same as begin mechanics to a mode
 *
 * Your mode must include at least a single () match group as that first match
 * group is what is used for comparison
 * @param {Partial<Mode>} mode
 */
declare const END_SAME_AS_BEGIN: (mode: any) => any;
declare var MODES: Readonly<{
    __proto__: null;
    MATCH_NOTHING_RE: RegExp;
    IDENT_RE: "[a-zA-Z]\\w*";
    UNDERSCORE_IDENT_RE: "[a-zA-Z_]\\w*";
    NUMBER_RE: "\\b\\d+(\\.\\d+)?";
    C_NUMBER_RE: "(-?)(\\b0[xX][a-fA-F0-9]+|(\\b\\d+(\\.\\d*)?|\\.\\d+)([eE][-+]?\\d+)?)";
    BINARY_NUMBER_RE: "\\b(0b[01]+)";
    RE_STARTERS_RE: "!|!=|!==|%|%=|&|&&|&=|\\*|\\*=|\\+|\\+=|,|-|-=|/=|/|:|;|<<|<<=|<=|<|===|==|=|>>>=|>>=|>=|>>>|>>|>|\\?|\\[|\\{|\\(|\\^|\\^=|\\||\\|=|\\|\\||~";
    SHEBANG: (opts?: {}) => any;
    BACKSLASH_ESCAPE: {
        begin: string;
        relevance: number;
    };
    APOS_STRING_MODE: {
        scope: string;
        begin: string;
        end: string;
        illegal: string;
        contains: {
            begin: string;
            relevance: number;
        }[];
    };
    QUOTE_STRING_MODE: {
        scope: string;
        begin: string;
        end: string;
        illegal: string;
        contains: {
            begin: string;
            relevance: number;
        }[];
    };
    PHRASAL_WORDS_MODE: {
        begin: RegExp;
    };
    COMMENT: (begin: any, end: any, modeOptions?: {}) => any;
    C_LINE_COMMENT_MODE: any;
    C_BLOCK_COMMENT_MODE: any;
    HASH_COMMENT_MODE: any;
    NUMBER_MODE: {
        scope: string;
        begin: string;
        relevance: number;
    };
    C_NUMBER_MODE: {
        scope: string;
        begin: string;
        relevance: number;
    };
    BINARY_NUMBER_MODE: {
        scope: string;
        begin: string;
        relevance: number;
    };
    REGEXP_MODE: {
        begin: RegExp;
        contains: {
            scope: string;
            begin: RegExp;
            end: RegExp;
            illegal: RegExp;
            contains: ({
                begin: string;
                relevance: number;
            } | {
                begin: RegExp;
                end: RegExp;
                relevance: number;
                contains: {
                    begin: string;
                    relevance: number;
                }[];
            })[];
        }[];
    };
    TITLE_MODE: {
        scope: string;
        begin: string;
        relevance: number;
    };
    UNDERSCORE_TITLE_MODE: {
        scope: string;
        begin: string;
        relevance: number;
    };
    METHOD_GUARD: {
        begin: string;
        relevance: number;
    };
    END_SAME_AS_BEGIN: (mode: any) => any;
}>;
/**
@typedef {import('highlight.js').CallbackResponse} CallbackResponse
@typedef {import('highlight.js').CompilerExt} CompilerExt
*/
/**
 * Skip a match if it has a preceding dot
 *
 * This is used for `beginKeywords` to prevent matching expressions such as
 * `bob.keyword.do()`. The mode compiler automatically wires this up as a
 * special _internal_ 'on:begin' callback for modes with `beginKeywords`
 * @param {RegExpMatchArray} match
 * @param {CallbackResponse} response
 */
declare function skipIfHasPrecedingDot(match: any, response: any): void;
/**
 *
 * @type {CompilerExt}
 */
declare function scopeClassName(mode: any, _parent: any): void;
/**
 * `beginKeywords` syntactic sugar
 * @type {CompilerExt}
 */
declare function beginKeywords(mode: any, parent: any): void;
/**
 * Allow `illegal` to contain an array of illegal values
 * @type {CompilerExt}
 */
declare function compileIllegal(mode: any, _parent: any): void;
/**
 * `match` to match a single expression for readability
 * @type {CompilerExt}
 */
declare function compileMatch(mode: any, _parent: any): void;
/**
 * provides the default 1 relevance to all modes
 * @type {CompilerExt}
 */
declare function compileRelevance(mode: any, _parent: any): void;
declare const beforeMatchExt: (mode: any, parent: any) => void;
declare const COMMON_KEYWORDS: string[];
declare const DEFAULT_KEYWORD_SCOPE = "keyword";
/**
 * Given raw keywords from a language definition, compile them.
 *
 * @param {string | Record<string,string|string[]> | Array<string>} rawKeywords
 * @param {boolean} caseInsensitive
 */
declare function compileKeywords(rawKeywords: any, caseInsensitive: any, scopeName?: string): any;
/**
 * Returns the proper score for a given keyword
 *
 * Also takes into account comment keywords, which will be scored 0 UNLESS
 * another score has been manually assigned.
 * @param {string} keyword
 * @param {string} [providedScore]
 */
declare function scoreForKeyword(keyword: any, providedScore: any): number;
/**
 * Determines if a given keyword is common or not
 *
 * @param {string} keyword */
declare function commonKeyword(keyword: any): boolean;
/**
 * @type {Record<string, boolean>}
 */
declare const seenDeprecations: {};
/**
 * @param {string} message
 */
declare const error: (message: any) => void;
/**
 * @param {string} message
 * @param {any} args
 */
declare const warn: (message: any, ...args: any[]) => void;
/**
 * @param {string} version
 * @param {string} message
 */
declare const deprecated: (version: any, message: any) => void;
/**
@typedef {import('highlight.js').CompiledMode} CompiledMode
*/
declare const MultiClassError: Error;
/**
 * Renumbers labeled scope names to account for additional inner match
 * groups that otherwise would break everything.
 *
 * Lets say we 3 match scopes:
 *
 *   { 1 => ..., 2 => ..., 3 => ... }
 *
 * So what we need is a clean match like this:
 *
 *   (a)(b)(c) => [ "a", "b", "c" ]
 *
 * But this falls apart with inner match groups:
 *
 * (a)(((b)))(c) => ["a", "b", "b", "b", "c" ]
 *
 * Our scopes are now "out of alignment" and we're repeating `b` 3 times.
 * What needs to happen is the numbers are remapped:
 *
 *   { 1 => ..., 2 => ..., 5 => ... }
 *
 * We also need to know that the ONLY groups that should be output
 * are 1, 2, and 5.  This function handles this behavior.
 *
 * @param {CompiledMode} mode
 * @param {Array<RegExp | string>} regexes
 * @param {{key: "beginScope"|"endScope"}} opts
 */
declare function remapScopeNames(mode: any, regexes: any, { key }: {
    key: any;
}): void;
/**
 * @param {CompiledMode} mode
 */
declare function beginMultiClass(mode: any): void;
/**
 * @param {CompiledMode} mode
 */
declare function endMultiClass(mode: any): void;
/**
 * this exists only to allow `scope: {}` to be used beside `match:`
 * Otherwise `beginScope` would necessary and that would look weird

  {
    match: [ /def/, /\w+/ ]
    scope: { 1: "keyword" , 2: "title" }
  }

 * @param {CompiledMode} mode
 */
declare function scopeSugar(mode: any): void;
/**
 * @param {CompiledMode} mode
 */
declare function MultiClass(mode: any): void;
/**
@typedef {import('highlight.js').Mode} Mode
@typedef {import('highlight.js').CompiledMode} CompiledMode
@typedef {import('highlight.js').Language} Language
@typedef {import('highlight.js').HLJSPlugin} HLJSPlugin
@typedef {import('highlight.js').CompiledLanguage} CompiledLanguage
*/
/**
 * Compiles a language definition result
 *
 * Given the raw result of a language definition (Language), compiles this so
 * that it is ready for highlighting code.
 * @param {Language} language
 * @returns {CompiledLanguage}
 */
declare function compileLanguage(language: any): any;
/**
 * Determines if a mode has a dependency on it's parent or not
 *
 * If a mode does have a parent dependency then often we need to clone it if
 * it's used in multiple places so that each copy points to the correct parent,
 * where-as modes without a parent can often safely be re-used at the bottom of
 * a mode chain.
 *
 * @param {Mode | null} mode
 * @returns {boolean} - is there a dependency on the parent?
 * */
declare function dependencyOnParent(mode: any): any;
/**
 * Expands a mode or clones it if necessary
 *
 * This is necessary for modes with parental dependenceis (see notes on
 * `dependencyOnParent`) and for nodes that have `variants` - which must then be
 * exploded into their own individual modes at compile time.
 *
 * @param {Mode} mode
 * @returns {Mode | Mode[]}
 * */
declare function expandOrCloneMode(mode: any): any;
declare var version: string;
declare class HTMLInjectionError extends Error {
    constructor(reason: any, html: any);
}
/**
@typedef {import('highlight.js').Mode} Mode
@typedef {import('highlight.js').CompiledMode} CompiledMode
@typedef {import('highlight.js').CompiledScope} CompiledScope
@typedef {import('highlight.js').Language} Language
@typedef {import('highlight.js').HLJSApi} HLJSApi
@typedef {import('highlight.js').HLJSPlugin} HLJSPlugin
@typedef {import('highlight.js').PluginEvent} PluginEvent
@typedef {import('highlight.js').HLJSOptions} HLJSOptions
@typedef {import('highlight.js').LanguageFn} LanguageFn
@typedef {import('highlight.js').HighlightedHTMLElement} HighlightedHTMLElement
@typedef {import('highlight.js').BeforeHighlightContext} BeforeHighlightContext
@typedef {import('highlight.js/private').MatchType} MatchType
@typedef {import('highlight.js/private').KeywordData} KeywordData
@typedef {import('highlight.js/private').EnhancedMatch} EnhancedMatch
@typedef {import('highlight.js/private').AnnotatedError} AnnotatedError
@typedef {import('highlight.js').AutoHighlightResult} AutoHighlightResult
@typedef {import('highlight.js').HighlightOptions} HighlightOptions
@typedef {import('highlight.js').HighlightResult} HighlightResult
*/
declare const inherit: typeof inherit$1;
declare const NO_MATCH: unique symbol;
declare const MAX_KEYWORD_HITS = 7;
/**
 * @param {any} hljs - object that is extended (legacy)
 * @returns {HLJSApi}
 */
declare const HLJS: (hljs: any) => any;
declare var highlight: any;
